import { Component, OnInit } from '@angular/core';
import { IonicModule } from '@ionic/angular';

import * as Parse from 'parse';
import { AgreementComponent } from '../../login/agreement/agreement.component';
import { AlertController, ModalController } from '@ionic/angular';
import { Router } from '@angular/router';
import { AuthService } from '../../../services/auth.service';
@Component({
  selector: 'app-my',
  templateUrl: './my.component.html',
  styleUrls: ['./my.component.scss'],
  standalone: true,
  imports: [IonicModule],
})
export class MyComponent implements OnInit {
  user?: Parse.Object = Parse.User.current();
  constructor(
    private modalController: ModalController,
    private alertController: AlertController,
    public authServ: AuthService,
    private router: Router
  ) {}
  tools: Array<{ icon: string; title: string; path: string }> = [
    {
      icon: '/img/钱包.png',
      title: '钱包',
      path: 'account/wattle',
    },
    {
      icon: '/img/相册.png',
      title: '相册',
      path: 'user/album',
    },
    {
      icon: '/img/邀请.png',
      title: '邀请',
      path: '',
    },
    {
      icon: '/img/设置.png',
      title: '设置',
      path: '',
    },
  ];
  registerAgreement: any; //用户协议
  liveAgreement: any; //直播协议
  company: string | null = localStorage?.getItem('company');
  ngOnInit() {
    this.getAgreement();
  }
  getAgreement() {
    let Agreement = new Parse.Query('ContractAgreement');
    Agreement.equalTo('company', this.company);
    Agreement.equalTo('type', 'register');
    Agreement.first().then((res) => {
      console.log(res);
      this.registerAgreement = res;
    });
    let Agreement2 = new Parse.Query('ContractAgreement');
    Agreement2.equalTo('company', this.company);
    Agreement2.equalTo('type', 'live');
    Agreement2.first().then((res) => {
      console.log(res);
      this.liveAgreement = res;
    });
  }
  toUrl(url: string, params?: Object) {
    console.log(url);
    if (params) {
      this.router.navigate([url, Object]);
    } else {
      this.router.navigate([url]);
    }
  }
  async showAgreement(type: string) {
    if (type == 'liveAgreement' || type == 'registerAgreement') {
      const modal = await this.modalController.create({
        component: AgreementComponent,
        cssClass: 'my-custom-class',
        componentProps: {
          agreement: this[type],
        },
      });
      return await modal.present();
    }
  }
  async onLogout(){
      const alert = await this.alertController.create({
      cssClass: 'my-custom-class',
      header: '',
      message: '你确定退出登录吗？',
      buttons: [
        {
          text: '确定',
          role: 'cancel',
          cssClass: 'secondary',
          handler: (blah) => {
            console.log('Confirm Cancel: blah');
            this.authServ.logout()
          },
        },
        {
          text: '取消',
          handler: () => {
          },
        },
      ],
    });
    await alert.present();
  }
}
